@@ -162,4 +162,25 @@ typedef enum
     G_DESKTOP_LOCATION_ACCURACY_LEVEL_EXACT
 } GDesktopLocationAccuracyLevel;
 
+typedef enum
+{
+  G_DESKTOP_TOUCHPAD_SCROLL_METHOD_DISABLED,
+  G_DESKTOP_TOUCHPAD_SCROLL_METHOD_EDGE_SCROLLING,
+  G_DESKTOP_TOUCHPAD_SCROLL_METHOD_TWO_FINGER_SCROLLING
+} GDesktopTouchpadScrollMethod;
+
+typedef enum
+{
+  G_DESKTOP_TOUCHPAD_HANDEDNESS_RIGHT,
+  G_DESKTOP_TOUCHPAD_HANDEDNESS_LEFT,
+  G_DESKTOP_TOUCHPAD_HANDEDNESS_MOUSE
+} GDesktopTouchpadHandedness;
+
+typedef enum
+{
+  G_DESKTOP_DEVICE_SEND_EVENTS_ENABLED,
+  G_DESKTOP_DEVICE_SEND_EVENTS_DISABLED,
+  G_DESKTOP_DEVICE_SEND_EVENTS_DISABLED_ON_EXTERNAL_MOUSE
+} GDesktopDeviceSendEvents;
+
 #endif /* __gdesktop_enums_h__ */
